@@ -1,7 +1,7 @@
 """Utilizario de funciones usadas en los procesos de robotizacion
    con Python."""
 
-__version__ = "1.33"
+__version__ = "1.34"
 __author__ = "Jonathan Bolo"
 
 from ctypes.wintypes import PUINT
@@ -783,12 +783,12 @@ def sqlcmd(file_sql:StrOrPath,
     
     
     cmd = (sqlcmd_bin + ' -e -y 0'  + 
-                        ' -i ' + str(file_sql_tmp)       +
-                        ' -o ' + str(file_sql_log)       +
+                        ' -i "' + str(file_sql_tmp)      + '"' +
+                        ' -o "' + str(file_sql_log)      + '"' +
                         ' -S ' + credentials['hostname'] +
                         ' -d ' + credentials['database'] + 
-                        ' -U \'' + credentials['username'] + '\'' +
-                        ' -P \'' + credentials['password'] + '\'' +
+                        ' -U "' + credentials['username'] + '"' +
+                        ' -P "' + credentials['password'] + '"' +
                         ' -f ' + coding )
     
     log.debug("Ejecutando sql")
@@ -858,11 +858,11 @@ def bcp(table,
 
     cmd = (bcpcmd_bin + ' ' + table + ' ' + 
            operation + ' "' + str(file) + '"' + 
-           ' -e ' + str(file_sql_log)       +
+           ' -e "' + str(file_sql_log) + '"' + 
            ' -S ' + credentials['hostname'] +
            ' -d ' + credentials['database'] + 
-           ' -U \'' + credentials['username'] + '\'' +
-           ' -P \'' + credentials['password'] + '\'' +
+           ' -U "' + credentials['username'] + '"' +
+           ' -P "' + credentials['password'] + '"' +
            ' -c ' + coding +
            ' -b1000 -m1000 -t"|"' )
     
